/*
 * Copyright 2019 by Kappich Systemberatung Aachen
 * ALL RIGHTS RESERVED.
 */

package de.bsvrz.dav.daf.accessControl.internal;

import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.dav.daf.main.config.SystemObjectType;

import java.util.Collection;

/**
 * Kapselt einen Block wie "AuswahlBereich", "AuswahlObjekte" etc. Entspricht aber nicht direkt den DatenmodellBlöcken, da je nach gesetzten Parametern
 * optimierte Klassen benutzt werden
  *
 * @author Kappich Systemberatung
 * @version $Revision: 0000 $
 */
public interface ObjectSelectionBlock {

	/**
	 * Prüft ob das übergebene Objekt in diesem Block enthalten ist
	 *
	 * @param object Testobjekt
	 *
	 * @return true wenn enthalten
	 */
	boolean contains(SystemObject object);

	/**
	 * Gibt alle Objekte in dem Block zurück. Der Aufruf sollte, falls möglich, vermieden werden, da der Vorgang je nach Definition sehr lange dauern kann
	 *
     * @param type Liste mit Systemobjekttypen die beachtet werden sollen.
	 * @return Liste mit Systemobjekten
	 */
	Collection<SystemObject> getAllObjects(final Collection<? extends SystemObjectType> type);

	/**
	 * Gibt alle Objekttypen zurück, die in diesem Block betrachtet werden, bzw. nach denen gefiltert wird. Alle mit {@link #getAllObjects(java.util.Collection)}
	 * zurückgelieferten Objekte sind zwingend von diesen Typen, umgekehrt ist allerdings nicht sichergestellt, dass zu allen hier zurückgelieferten Typen auch
	 * Objekte vorhanden sind.
	 *
	 * @return Liste mit allen Typen
	 */
	Collection<SystemObjectType> getAllObjectTypes();

	/**
	 * Erstellt einen Listener, der Objekte über das Ändern dieses Blocks benachrichtigt
	 *
	 * @param object Listener
	 */
	void addChangeListener(ObjectCollectionChangeListener object);

	/**
	 * Entfernt einen Listener, der Objekte über das Ändern dieses Blocks benachrichtigt
	 *
	 * @param object Listener
	 */
	void removeChangeListener(ObjectCollectionChangeListener object);

	/**
	 * Markiert das Objekt als unbenutzt, sodass angemeldete Listener etc. abgemeldet werden können
	 */
	void dispose();
}
